/* 
 * THC-Shagg - A modular application to bruteforce check digit algorithms
 * (c) 2001 Plasmoid <plasmoid@thehackerschoice.com>
 * The Hacker's Choice, http://www.thehackerschoice.com
 * $Id: PartitionSet.java,v 1.4 2001/12/13 13:28:24 plasmoid Exp $ 
 */
package com.thehackerschoice.shagg;

import java.util.Vector;
/**
 * This class holds a set of partitions for a specified length, the length
 * of the serial numbers. A partition is defined as an offset, the subnumber
 * and a trailing end. The algorithms will only be applied to the subnumber. 
 * <p>
 * The set contains all possible partitions for the given length and
 * minimum.
 * <p>
 * e.g. partition 5, minimum 3<ul><tt>
 * (0,5,0), (1,4,0), (2,3,0), (1,3,1), (0,3,2), (0,4,1)
 * </tt></ul>
 *
 * @version $Id: PartitionSet.java,v 1.4 2001/12/13 13:28:24 plasmoid Exp $
 * @author Plasmoid (plasmoid@thehackerschoice.com),
 *                  <a href="http://www.thehackerschoice.com">THC</a>
 */   
public class PartitionSet 
{
   private Vector set;

   /**
    * Construct a partition set. 
    * @param len Length of the field to partition.
    * @param min Minimum of offset of element size.
    */
   public PartitionSet(int len, int min) {
      int[] partition;
      
      set=new Vector();
      
      for(int l=len;l>=min;l--) {
         for(int o=0;o<=len-l;o++) {
            partition = new int[3];
            partition[0]=o;
            partition[1]=l;
            partition[2]=len-l-o;
            set.add(partition);
         }
      }
   }

   /**
    * Get the size of the set.
    * @return size Size of the partition set.
    */
   public int size() {
      return set.size();
   }
   
   /**
    * Get the i-th element of the set.
    * @param i Index of the element
    * @return Partition as an array of integers.
    */
   public int[] get(int i) {
      return (int[]) set.get(i);
   }
}
