/* 
 * THC-Shagg - A modular application to bruteforce check digit algorithms
 * (c) 2001 Plasmoid <plasmoid@thehackerschoice.com>                      
 * The Hacker's Choice, http://www.thehackerschoice.com
 * $Id: Modulus10AlgorithmBasic.java,v 1.5 2001/12/13 13:28:25 plasmoid Exp $ 
 */
package com.thehackerschoice.shagg.algorithms;

/**
 * The basic or typical implementation of the Modulus 10 Algorithm.
 * The elements are added using a simple "+" and the check digit is 
 * the last digit of the sequence. 
 *
 * @version $Id: Modulus10AlgorithmBasic.java,v 1.5 2001/12/13 13:28:25 plasmoid Exp $
 * @author Plasmoid (plasmoid@thehackerschoice.com),
 *                  <a href="http://www.thehackerschoice.com">THC</a>
 */
public class Modulus10AlgorithmBasic extends Modulus10Algorithm
{
   /*
    * Init the Modulus 10 Basic Algorithm.
    */
   public Modulus10AlgorithmBasic() {
      type="B";
   }

   /**
    * Add method for the Modulus 10 Algorithm. Elements are just added
    * using "+" after they have been multilpied with the given weights.
    * @param sequence Integer sequence representing the digits to check,
    *                 not necessary between 0 and 9.
    * @param weights  Integer sequence of the weights to use, may be of
    *                 any length.
    * @param index    Current index
    * @return Sum at index.
    */
   public int mod10Add(int[] sequence, int[] weights, int index) {
      return sequence[index]*weights[index%weights.length];
   }
   
   /**
    * Check method for the Modulus 10 Algorithm. The last digit represents
    * the check digit.
    * @param sequence Integer sequence representing the digits to check,
    *                 not necessary between 0 and 9.
    * @return The check digit.
    */
   public int mod10checkDigit(int[] sequence) {
      return sequence[sequence.length-1];
   }
   
}
