/* 
 * THC-Shagg - A modular application to bruteforce check digit algorithms
 * (c) 2001 Plasmoid <plasmoid@thehackerschoice.com>                      
 * The Hacker's Choice, http://www.thehackerschoice.com
 * $Id: Modulus10AlgorithmCC.java,v 1.5 2001/12/13 13:28:25 plasmoid Exp $ 
 */
package com.thehackerschoice.shagg.algorithms;

/**
 * The algorithm used in Credit Cards is claimed to be the Luhn Algorithm.
 * In fact it is a variant that uses an extra check digit that is always 
 * 0.
 *
 * @version $Id: Modulus10AlgorithmCC.java,v 1.5 2001/12/13 13:28:25 plasmoid Exp $
 * @author Plasmoid (plasmoid@thehackerschoice.com),
 *                  <a href="http://www.thehackerschoice.com">THC</a>
 */
public class Modulus10AlgorithmCC extends Modulus10AlgorithmLuhn
{

   /**
    * Init the Modulus 10 CC Algorithm.
    */
   public Modulus10AlgorithmCC() {
      type="CC";
   }

   /**
    * Checks if the supplied sequence matches the Modulus 10 Algorithm.
    * Modulus 10 uses the provided weights. The last digit is not used
    * as a check digit! That's the difference to all other Modulus 10
    * algorithms.
    * @param sequence Integer sequence representing the digits to check,
    *                 not necessary between 0 and 9.
    * @param weights  Integer sequence of the weights to use, may be of
    *                 any length.
    * @return wether sequences matches the algorithm.
    */
   public boolean check(int[] sequence, int[] weights) {
      long result=0;
      
      for(int i=0; i<sequence.length; i++) 
         result+=mod10Add(sequence,weights,i);

      return (result%10)==mod10checkDigit(sequence);
   }
   
   /** 
    * The result of the modulus operation is compared to 0 in all cases.    
    * @param sequence Integer sequence representing the digits to check,
    *                 not necessary between 0 and 9.
    * @return The check digit.
    */
   public int mod10checkDigit(int[] sequence) {
      return 0;
   }

   /**
    * Return the check digit position inside the sequence. Modulus 10 uses
    * no check digit from the given sequence.
    * @param sequence Length of the integer sequence representing the digits to check,
    *                 not necessary between 0 and 9.
    * @return Position of the check digit.
    */
   public int getCheckDigitPosition(int sequence) {
      return -1;
   }
   
}
